import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PrivateKeyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Name of the algorithm to use to generate the private key
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/private_key#algorithm PrivateKey#algorithm}
    */
    readonly algorithm: string;
    /**
    * ECDSA curve to use when generating a key
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/private_key#ecdsa_curve PrivateKey#ecdsa_curve}
    */
    readonly ecdsaCurve?: string;
    /**
    * Number of bits to use when generating an RSA key
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/private_key#rsa_bits PrivateKey#rsa_bits}
    */
    readonly rsaBits?: number;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/tls/r/private_key tls_private_key}
*/
export declare class PrivateKey extends cdktf.TerraformResource {
    static readonly tfResourceType = "tls_private_key";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/tls/r/private_key tls_private_key} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PrivateKeyConfig
    */
    constructor(scope: Construct, id: string, config: PrivateKeyConfig);
    private _algorithm?;
    get algorithm(): string;
    set algorithm(value: string);
    get algorithmInput(): string | undefined;
    private _ecdsaCurve?;
    get ecdsaCurve(): string;
    set ecdsaCurve(value: string);
    resetEcdsaCurve(): void;
    get ecdsaCurveInput(): string | undefined;
    get id(): string;
    get privateKeyPem(): string;
    get publicKeyFingerprintMd5(): string;
    get publicKeyOpenssh(): string;
    get publicKeyPem(): string;
    private _rsaBits?;
    get rsaBits(): number;
    set rsaBits(value: number);
    resetRsaBits(): void;
    get rsaBitsInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
